@@ -3,13 +3,16 @@ package net.reduls.igo.dictionary;
 import java.io.IOException;
 import java.util.List;
 
+/**
+ * 未知語の検索を行うクラス
+ */
 public final class Unknown {
-    private final CharCategory category;
-    private final int spaceId;
+    private final CharCategory category;  // 文字カテゴリ管理クラス
+    private final int spaceId;            // 文字カテゴリがSPACEの文字のID
 
     public Unknown(String dataDir) throws IOException {
 	category = new CharCategory(dataDir);
-	spaceId = category.category(' ').id;
+	spaceId = category.category(' ').id;  // NOTE: ' 'の文字カテゴリはSPACEに予約されている
     }
     
     public void search(String text, int start, WordDic wdic, List<ViterbiNode> result) {
@@ -20,25 +23,24 @@ public final class Unknown {
 	    return;
 	
 	final boolean isSpace = ct.id==spaceId;
-	boolean b=true;
 	final int limit = Math.min(text.length(), ct.length+start);
+	boolean finished = false;
 	int i=start;
 	for(; i < limit; i++) { 
-	    wdic.searchFromId(ct.id, start, (i-start)+1, isSpace, result);
-	    if(i+1!=limit &&
-	       category.isCompatible(ch, text.charAt(i+1)) == false) {
-		b=false;
+	    wdic.searchFromTrieId(ct.id, start, (i-start)+1, isSpace, result);
+	    if(i+1!=limit && category.isCompatible(ch, text.charAt(i+1)) == false) {
+		finished = true;
 		break;
 	    }
 	}
 	
-	if(ct.group && b && i < text.length()) {
+	if(ct.group && !finished && i < text.length()) {
 	    for(; i < text.length(); i++)
 		if(category.isCompatible(ch, text.charAt(i)) == false) {
-		    wdic.searchFromId(ct.id, start, i-start, isSpace, result);
+		    wdic.searchFromTrieId(ct.id, start, i-start, isSpace, result);
 		    return;
 		}
-	    wdic.searchFromId(ct.id, start, text.length()-start, isSpace, result);
+	    wdic.searchFromTrieId(ct.id, start, text.length()-start, isSpace, result);
 	}
     }
 }
\ No newline at end of file
